use std::fmt::Display;

#[derive(Copy, Clone)]
pub struct StationMeasurements {
    pub min: isize,
    pub max: isize,
    pub count: isize,
    pub sum: isize,
}

impl StationMeasurements {
    pub fn update(&mut self, v: isize) {
        self.min = self.min.min(v);
        self.max = self.max.max(v);
        self.count += 1;
        self.sum += v;
    }

    pub fn merge(&mut self, other: &Self) {
        self.min = self.min.min(other.min);
        self.max = self.max.max(other.max);
        self.count += other.count;
        self.sum += other.sum;
    }
}

impl Display for StationMeasurements {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        let min_pre = self.min / 10;
        let min_suf = (self.min % 10).abs();
        let max_pre = self.max / 10;
        let max_suf = (self.max % 10).abs();
        // casting here is faster
        let avg = (self.sum as f64 / self.count as f64) / 10.0;
        write!(f, "{min_pre}.{min_suf}/{avg:.1}/{max_pre}.{max_suf}")
    }
}
