#[inline]
pub fn get(bytes: &[u8], find: u8) -> Option<u32> {
    let chunks = bytes.windows(4);
    for (pos, chunk) in chunks.enumerate() {
        let inner_pos = get_pos_in_chunk(chunk, find);
        if inner_pos < chunk.len() as u32 {
            return Some(pos as u32 + inner_pos);
        }
    }
    None
}

#[inline]
fn get_pos_in_chunk(byte_chunk: &[u8], find: u8) -> u32 {
    let find_hex = u32::from_be_bytes([find; 4]);
    let x = u32::from_be_bytes(byte_chunk.try_into().unwrap()) ^ find_hex;
    let mask = (x - 0x01010101) & (!x & (0x80808080));
    u32::leading_zeros(mask) >> 3
}

#[cfg(test)]
mod tests {
    use crate::utils::byte_pos::get;

    #[test]
    fn test_getpos() {
        let semi_bytes = vec![
            0_u8, 0_u8, 0_u8, 0_u8, 0_u8, 0_u8, 0_u8, 0_u8, b';', 0_u8, 0_u8,
        ];
        let semi_bytes = semi_bytes.as_slice();
        let pos = get(semi_bytes, b';').unwrap();
        assert_eq!(pos, 8);
    }

    #[test]
    fn test_getpos_empty() {
        let semi_bytes = vec![0_u8, 0_u8, 0_u8, 0_u8, 0_u8, 0_u8, 0_u8, 0_u8, 0_u8, 0_u8];
        let semi_bytes = semi_bytes.as_slice();
        let pos = get(semi_bytes, b';');
        assert_eq!(pos, None);
    }
}
